@@ -162,6 +162,18 @@ def savefig(dirname, fname):
     return None
 
 
+def plot_polygon(*points, ax, color="teal", alpha=0.1):
+    points = [*points]
+    points.append(points[0])
+
+    x, y = zip(*points)
+    ax.fill(x, y, color=color, alpha=0.1)
+    ax.plot(x, y, color="black", alpha=1, lw=1.5)
+    ax.plot(x, y, "ko", markersize=8, alpha=0.7)
+
+    return None
+
+
 def histogram(
     xmin,
     frequencies,
